@@ -1,11 +1,11 @@
 # Copyright (C) 2011-2021 Andrea Francia Bereguardo(PV) Italy
 import argparse
 
-from .fstab import volume_of
+from .fstab import volume_of, VolumesListing
 from .list import TrashDirsSelector
 from .trash import (TopTrashDirRules, TrashDirReader, path_of_backup_copy,
                     print_version, println, Clock, parse_deletion_date,
-                    trash_dir_found, UserInfoProvider, AllUsersInfoProvider)
+                    trash_dir_found, UserInfoProvider, AllUsersInfoProvider, my_input)
 from .trash import TrashDirsScanner
 from .trash import EX_OK
 import os
@@ -25,7 +25,7 @@ def main(argv=sys.argv,
         out=stdout,
         err=stderr,
         environ=environ,
-        list_volumes=os_mount_points,
+        volumes_listing=VolumesListing(os_mount_points),
         now=datetime.now,
         file_reader=FileSystemReader(),
         getuid=os.getuid,
@@ -73,7 +73,7 @@ class EmptyCmd:
                  out,
                  err,
                  environ,
-                 list_volumes,
+                 volumes_listing,
                  now,
                  file_reader,
                  getuid,
@@ -91,14 +91,14 @@ class EmptyCmd:
         trashcan = CleanableTrashcan(file_remover_with_error)
         user_info_provider = UserInfoProvider(environ, getuid)
         user_dir_scanner = TrashDirsScanner(user_info_provider,
-                                            list_volumes,
+                                            volumes_listing,
                                             TopTrashDirRules(file_reader))
         all_users_info_provider = AllUsersInfoProvider()
         all_users_scanner = TrashDirsScanner(all_users_info_provider,
-                                             list_volumes,
+                                             volumes_listing,
                                              TopTrashDirRules(file_reader))
-        self.selector = TrashDirsSelector(user_dir_scanner.scan_trash_dirs(),
-                                          all_users_scanner.scan_trash_dirs(),
+        self.selector = TrashDirsSelector(user_dir_scanner.scan_trash_dirs(environ),
+                                          all_users_scanner.scan_trash_dirs(environ),
                                           volume_of)
         trash_dir = TrashDirReader(self.file_reader)
         self.main_loop = MainLoop(trash_dir, trashcan)
@@ -106,8 +106,7 @@ class EmptyCmd:
     def run(self, *argv):
         program_name = os.path.basename(argv[0])
         self.errors = Errors(program_name, self.err)
-
-        parser = make_parser()
+        parser = make_parser(is_input_interactive())
         parsed = parser.parse_args(argv[1:])
 
         if parsed.version:
@@ -125,14 +124,34 @@ class EmptyCmd:
                                                   self.errors)
             trash_dirs = self.selector.select(parsed.all_users,
                                               parsed.user_specified_trash_dirs)
-            self.main_loop.do_loop(trash_dirs, delete_mode)
-        return EX_OK
+            guard = Guard() if parsed.interactive else NoGuard()
+            emptier = Emptier(self.main_loop, delete_mode)
 
+            user = User(prepare_output_message, my_input, parse_reply)
+            guard.ask_the_user(user, trash_dirs, emptier)
+        return EX_OK
 
     def print_cannot_remove_error(self, path):
         self.errors.print_error("cannot remove %s" % path)
 
 
+def is_input_interactive():
+    return os.isatty(0)
+
+
+def parse_reply(reply):
+    return reply[0:1].lower() == 'y'
+
+
+class Emptier:
+    def __init__(self, main_loop, delete_mode):
+        self.main_loop = main_loop
+        self.delete_mode = delete_mode
+
+    def do_empty(self, trash_dirs):
+        self.main_loop.do_loop(trash_dirs, self.delete_mode)
+
+
 class FileRemoveWithErrorHandling:
     def __init__(self, file_remover, on_error):
         self.file_remover = file_remover
@@ -193,7 +212,7 @@ class CleanableTrashcan:
         self._file_remover.remove_file(trashinfo_path)
 
 
-def make_parser():
+def make_parser(default_is_interactive):
     parser = argparse.ArgumentParser(
         description='Purge trashed files.',
         epilog='Report bugs to https://github.com/andreafrancia/trash-cli/issues')
@@ -206,17 +225,56 @@ def make_parser():
     parser.add_argument('--print-time', action='store_true', dest='print_time',
                         help=argparse.SUPPRESS)
     parser.add_argument('--all-users', action='store_true', dest='all_users',
-                        help=argparse.SUPPRESS)
+                        help='empty all trashcan of all the users')
+    parser.add_argument('-i',
+                        '--interactive',
+                        action='store_true',
+                        dest='interactive',
+                        help='ask before emptying trash directories',
+                        default=default_is_interactive)
+    parser.add_argument('-f',
+                        action='store_false',
+                        help='don\'t ask before emptying trash directories',
+                        dest='interactive')
     parser.add_argument('days', action='store', default=None, type=int,
                         nargs='?')
     return parser
 
 
 class Guard:
-    def __init__(self, emptier):
-        self.emptier = emptier
 
-    def ask_the_user(self, user, trash_dirs):
+    def ask_the_user(self, user, trash_dirs, emptier):
         trash_dirs_list = list(trash_dirs)
         if user.do_you_wanna_empty_trash_dirs(trash_dirs_list):
-            self.emptier(trash_dirs_list)
+            emptier.do_empty(trash_dirs_list)
+
+
+class NoGuard:
+
+    def ask_the_user(self, _user, trash_dirs, emptier):
+        emptier.do_empty(trash_dirs)
+
+
+class User:
+    def __init__(self, prepare_output_message, input, parse_reply):
+        self.prepare_output_message = prepare_output_message
+        self.input = input
+        self.parse_reply = parse_reply
+
+    def do_you_wanna_empty_trash_dirs(self, trash_dirs):
+        reply = self.input(self.prepare_output_message(trash_dirs))
+        return self.parse_reply(reply)
+
+
+def prepare_output_message(trash_dirs):
+    result = []
+    if trash_dirs:
+        result.append("Would empty the following trash directories:")
+        for event, args in trash_dirs:
+            if event == trash_dir_found:
+                trash_dir, volume = args
+                result.append("    - %s" % trash_dir)
+        result.append("Proceed? (y/n) ")
+        return "\n".join(result)
+    else:
+        return 'No trash directories to empty.\n'
