@@ -1,9 +1,11 @@
+# Copyright (C) 2011-2021 Andrea Francia Bereguardo(PV) Italy
 import argparse
 import os
 
+from . import fstab
 from .fs import FileSystemReader, file_size
-from .fstab import volume_of
-from .trash import (version, TrashDir, path_of_backup_copy, print_version,
+from .fstab import volume_of, VolumesListing
+from .trash import (version, TrashDirReader, path_of_backup_copy, print_version,
                     maybe_parse_deletion_date, trash_dir_found,
                     trash_dir_skipped_because_parent_is_symlink,
                     trash_dir_skipped_because_parent_not_sticky, UserInfoProvider)
@@ -11,28 +13,30 @@ from .trash import TopTrashDirRules
 from .trash import TrashDirsScanner
 from .trash import ParseError
 from .trash import parse_path
-from .trash import unknown_date
 
 def main():
     import sys
     import os
     from trashcli.list_mount_points import os_mount_points
     ListCmd(
-        out          = sys.stdout,
-        err          = sys.stderr,
-        environ      = os.environ,
-        getuid       = os.getuid,
-        list_volumes = os_mount_points,
+        out=sys.stdout,
+        err=sys.stderr,
+        environ=os.environ,
+        getuid=os.getuid,
+        volumes_listing=VolumesListing(os_mount_points),
     ).run(*sys.argv)
 
+
 class ListCmd:
-    def __init__(self, out,
-                       err,
-                       environ,
-                       list_volumes,
-                       getuid,
-                       file_reader = FileSystemReader(),
-                       version     = version):
+    def __init__(self,
+                 out,
+                 err,
+                 environ,
+                 volumes_listing,
+                 getuid,
+                 file_reader=FileSystemReader(),
+                 version=version,
+                 volume_of=fstab.volume_of):
 
         self.out          = out
         self.output       = ListCmdOutput(out, err)
@@ -41,10 +45,11 @@ class ListCmd:
         self.file_reader = file_reader
         user_info_provider = UserInfoProvider(environ, getuid)
         trashdirs_scanner = TrashDirsScanner(user_info_provider,
-                                             list_volumes,
+                                             volumes_listing,
                                              TopTrashDirRules(file_reader))
-        self.selector = TrashDirsSelector(trashdirs_scanner.scan_trash_dirs(),
-                                          [])
+        self.selector = TrashDirsSelector(trashdirs_scanner.scan_trash_dirs(environ),
+                                          [],
+                                          volume_of)
 
     def run(self, *argv):
         parser = maker_parser(os.path.basename(argv[0]))
@@ -64,7 +69,7 @@ class ListCmd:
         for event, args in trash_dirs:
             if event == trash_dir_found:
                 path, volume = args
-                trash_dir = TrashDir(self.file_reader)
+                trash_dir = TrashDirReader(self.file_reader)
                 for trash_info in trash_dir.list_trashinfo(path):
                     self._print_trashinfo(volume, trash_info, extractor, show_files)
             elif event == trash_dir_skipped_because_parent_not_sticky:
@@ -123,9 +128,10 @@ def description(program_name, printer):
 
 
 class TrashDirsSelector:
-    def __init__(self, current_user_dirs, all_users_dirs):
+    def __init__(self, current_user_dirs, all_users_dirs, volume_of):
         self.current_user_dirs = current_user_dirs
         self.all_users_dirs = all_users_dirs
+        self.volume_of = volume_of
 
     def select(self, all_users_flag, user_specified_dirs):
         if all_users_flag:
@@ -136,7 +142,7 @@ class TrashDirsSelector:
                 for dir in self.current_user_dirs:
                     yield dir
             for dir in user_specified_dirs:
-                yield trash_dir_found, (dir, volume_of(dir))
+                yield trash_dir_found, (dir, self.volume_of(dir))
 
 
 def maker_parser(prog):
